@@ -9,7 +9,7 @@ option '+config_base' => (
     default       => '.hpcrunner',
 );
 
-our $VERSION = '3.2.1';
+our $VERSION = '3.2.2';
 
 app_strict 0;
 
@@ -45,7 +45,9 @@ HPC::Runner::Command is a set of libraries for scaffolding data analysis project
 submitting and executing jobs on an HPC cluster or workstation, and obsessively
 logging results.
 
-Please see the complete documentation at L<HPC::Runner::Command GitBooks | https://jerowe.gitbooks.io/hpc-runner-command-docs/content/>
+Get help by heading on over to github and raising an issue L<https://github.com/biosails/HPC-Runner-Command/issues>.
+
+Please see the complete documentation at L<HPC::Runner::Command GitBooks | https://jerowe.gitbooks.io/hpc-runner-command-docs/content/>.
 
 =head1 Quick Start - Create a New Project
 
@@ -190,17 +192,25 @@ Jillian Rowe E<lt>jillian.e.rowe@gmail.comE<gt>
 
 =head1 Previous Release
 
-This software was previously released under L<HPC::Runner>. L<HPC::Runner::Command> is a complete rewrite of the existing library. While it is meant to have much of the same functionality, it is not backwords compatible.
+This software was previously released under L<HPC::Runner>.
+L<HPC::Runner::Command> is a complete rewrite of the existing library. While it
+is meant to have much of the same functionality, it is not backwords compatible.
 
 =head1 Acknowledgements
 
 As of Version 2.41:
 
-This modules continuing development is supported by NYU Abu Dhabi in the Center for Genomics and Systems Biology. With approval from NYUAD, this information was generalized and put on bitbucket, for which the authors would like to express their gratitude.
+This modules continuing development is supported by NYU Abu Dhabi in the Center
+for Genomics and Systems Biology. With approval from NYUAD, this information was
+generalized and put on bitbucket, for which the authors would like to express
+their gratitude.
 
 Before Version 2.41
 
-This module was originally developed at and for Weill Cornell Medical College in Qatar within ITS Advanced Computing Team. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical College in
+Qatar within ITS Advanced Computing Team. With approval from WCMC-Q, this
+information was generalized and put on github, for which the authors would like
+to express their gratitude.
 
 =head1 COPYRIGHT
 
