@@ -36,12 +36,17 @@ has 'read_command' => (
     lazy      => 1,
     default   => sub {
         my $self = shift;
-        if ( $self->can('task_id') ) {
+        if ( $self->can('task_id') && $self->can('batch_index_start') ) {
             return $self->task_id - $self->batch_index_start - 1;
         }
-        else {
+        elsif ( $self->can('batch_index_start') ) {
             return $self->batch_index_start;
         }
+        else {
+            $self->log->fatal(
+                'Not able to determine job execution type.  Exiting.');
+            exit 1;
+        }
     }
 );
 
@@ -99,6 +104,7 @@ has 'queue' => (
 has 'mce' => (
     is      => 'rw',
     lazy    => 1,
+    clearer => '_clear_mce',
     default => sub {
         my $self = shift;
         return MCE->new(
@@ -189,6 +195,8 @@ The default method of parsing the file.
 sub parse_file_mce {
     my $self = shift;
 
+    $self->process_table;
+    
     my $fh = IO::File->new( $self->infile, q{<} )
       or $self->log_main_messages( "fatal",
         "Error opening file  " . $self->infile . "  " . $! );
@@ -261,67 +269,74 @@ sub process_lines {
     if ( $line =~ m/^#TASK/ ) {
         $self->add_cmd($line);
     }
-    ##This should only be for single node mode
-    if ( $line =~ m/^#HPC procs=/ ) {
-        my ( $t1, $t2 ) = parse_meta($line);
-        $self->procs($t2);
-    }
+
+    $self->check_single_node($line) if $self->single_node;
 
     return if $line =~ m/^#/;
+    $self->add_cmd($line);
 
-    if ( $self->has_cmd ) {
-
-        #$DB::single = 2;
-        $self->add_cmd($line);
-        if ( $line =~ m/\\$/ ) {
-            return;
-        }
-        else {
-            $self->log_main_messages( 'debug',
-                "Enqueuing command:\n\t" . $self->cmd );
-            $self->queue->enqueue( $self->counter, $self->cmd );
-            $self->clear_cmd;
-            $self->inc_counter;
-        }
+    ##Bash style we continue to the next lime if the current line ends in \
+    return if $line =~ m/\\$/;
+    if ( $self->match_cmd(qr/^wait$/) ) {
+        $self->hold_pool;
     }
     else {
-        #$DB::single = 2;
-        $self->cmd($line);
-        if ( $line =~ m/\\$/ ) {
-            return;
-        }
-        ##TODO Update for single node mode
-        elsif ($self->match_cmd(qr/^wait$/)
-            || $self->match_cmd(qr/^HPC jobname/) )
-        {
-
-            #$DB::single = 2;
-            $self->log_main_messages( 'debug',
-                "Beginning command:\n\t" . $self->cmd );
-            $self->log_main_messages( 'debug',
-                'Waiting for all threads to complete...' );
-            $self->clear_cmd;
-
-            $self->wait(1);
-            push( @{ $self->jobref }, [] );
-            $self->queue->enqueue( (undef) x ( $self->procs * 2 ) );
-            $self->mce->run(0);    # 0 indicates do not shutdown after running
-
-            $self->log_main_messages( 'debug',
-                'All children have completed processing!' );
-        }
-        else {
-            $self->log_main_messages( 'debug',
-                "Enqueuing command:\n\t" . $self->cmd );
-
-            #$DB::single = 2;
-            $self->queue->enqueue( $self->counter, $self->cmd );
-            $self->clear_cmd;
-            $self->inc_counter;
-        }
+        $self->add_pool;
     }
 }
 
+sub check_single_node {
+    my $self = shift;
+    my $line = shift;
+
+    if ( $line =~ m/^#HPC jobname=/ ) {
+        $self->hold_pool;
+        $self->_clear_mce;
+        my ( $t1, $t2 ) = parse_meta($line);
+        $self->jobname($t2);
+        ##Trigger outdir
+        $self->logname($t2);
+        $self->logfile( $self->set_logfile );
+        $self->logdir( $self->set_logdir );
+    }
+    if ( $line =~ m/^#HPC procs=/ ) {
+        $self->hold_pool;
+        $self->_clear_mce;
+        my ( $t1, $t2 ) = parse_meta($line);
+        $self->procs($t2);
+        $self->hold_pool;
+    }
+}
+
+sub add_pool {
+    my $self = shift;
+    $self->log_main_messages( 'debug', "Enqueuing command:\n\t" . $self->cmd );
+
+    $self->queue->enqueue( $self->counter, $self->cmd )
+      if $self->has_cmd;
+    $self->clear_cmd;
+    $self->inc_counter;
+}
+
+sub hold_pool {
+    my $self = shift;
+
+    $self->log_main_messages( 'debug', "Beginning command:\n\t" . $self->cmd )
+      if $self->has_cmd;
+    $self->log_main_messages( 'debug',
+        'Waiting for all threads to complete...' )
+      if $self->has_cmd;
+
+    $self->wait(1);
+    push( @{ $self->jobref }, [] );
+    $self->queue->enqueue( (undef) x ( $self->procs * 2 ) );
+    $self->mce->run(0);    # 0 indicates do not shutdown after running
+
+    $self->log_main_messages( 'debug',
+        'All children have completed processing!' );
+    $self->clear_cmd;
+}
+
 memoize('parse_meta');
 
 sub parse_meta {
